@@ -14,6 +14,8 @@ from scipy import optimize
 import functools
 import math
 
+# Change matplotlib formatting. TODO incorporate into a style?
+plt.rcParams["patch.force_edgecolor"] = True
 
 def make_array(*elements):
     """Returns an array containing all the arguments passed to this function.
@@ -31,6 +33,10 @@ def make_array(*elements):
     >>> make_array()
     array([], dtype=float64)
     """
+    if elements and all(isinstance(item, (int, np.integer)) for item in elements):
+        # Specifically added for Windows machines where the default 
+        # integer is int32 - see GH issue #339.
+        return np.array(elements, dtype="int64")
     return np.array(elements)
 
 
@@ -159,20 +165,15 @@ def proportions_from_distribution(table, label, sample_size,
 def table_apply(table, func, subset=None):
     """Applies a function to each column and returns a Table.
 
-    Uses pandas `apply` under the hood, then converts back to a Table
-
     Args:
-        table : instance of Table
-            The table to apply your function to
-        func : function
-            Any function that will work with DataFrame.apply
-        subset : list | None
-            A list of columns to apply the function to. If None, function
-            will be applied to all columns in table
+        ``table``: The table to apply your function to.
 
-    Returns
-    -------
-    tab : instance of Table
+        ``func``: The function to apply to each column.
+
+        ``subset``: A list of columns to apply the function to; if None,
+            the function will be applied to all columns in table.
+
+    Returns:
         A table with the given function applied. It will either be the
         shape == shape(table), or shape (1, table.shape[1])
     """
